@@ -1,7 +1,7 @@
 package Mojolicious::Plugin::CSPHeader;
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 sub register {
     my ($self, $app, $conf) = @_;
@@ -31,10 +31,10 @@ sub register {
                     if (ref($conf->{directives}->{$key}) eq 'HASH') {
                         my $value = $conf->{directives}->{$key}->{base};
                         if ($conf->{directives}->{$key}->{ws}) {
-                            my $url = $c->req->url->to_abs
-                                         ->path('/')
-                                         ->scheme(($c->req->url->protocol =~ m/https|wss/) ? 'wss' : 'ws')
-                                         ->to_string;
+                            my $url = $c->req->url->to_abs;
+                            $url->path('/')
+                                ->scheme(($url->protocol =~ m/https|wss/) ? 'wss' : 'ws')
+                                ->to_string;
                             $url =~ s#/$##;
                             $value .= ' '.$url;
                         }
